@@ -8,6 +8,7 @@ dat <- data.frame(
   Cat = c("A", "A", "A", "B", "B", "B", "B", "A", NA, "B"),
   Fac = factor(c("A", "B", "C", "A", "B", "C", "A", "B", "C", "A")),
   Num = c(1, 2, 3, 4, 4, 3, 3, 4, 0, NA),
+  Num2 = c(1, 2, 1, 2, 2, 1, 2, 0, 2, NA),
   Ord = ordered(c("I", "II", "II", "III", "III", "III", "I", "III", "II", "I")),
   Lgl = c(TRUE, TRUE, FALSE, TRUE, FALSE, TRUE, TRUE, FALSE, FALSE, FALSE),
   Dat = as.Date("2018-05-01") + c(1, 1, 2, 2, 3, 4, 5, 6, 3, 4),
@@ -47,7 +48,7 @@ for(i in 1:3)
         "|-  FALSE     |        3 (60.0%)        |        2 (40.0%)        |    2 (100.0%)    |        |",
         "|-  TRUE      |        2 (40.0%)        |        3 (60.0%)        |    1 (50.0%)     |        |",
         "|Dat          |                         |                         |                  |   0.182|",
-        "|-  median    |       2018-05-04        |       2018-05-05        |      0.500       |        |",
+        "|-  Median    |       2018-05-04        |       2018-05-05        |      0.500       |        |",
         "|-  Range     | 2018-05-02 - 2018-05-06 | 2018-05-02 - 2018-05-07 |  0.000 - 1.000   |        |"
       )
     )
@@ -83,7 +84,7 @@ for(i in 1:3)
         "|-  TRUE      |        2 (40.0%)        |        3 (60.0%)        |    1 (50.0%)     |        |",
         "|Dat          |                         |                         |                  |   0.182|",
         "|-  N-Miss    |            1            |            1            |        2         |        |",
-        "|-  median    |       2018-05-04        |       2018-05-05        |      0.500       |        |",
+        "|-  Median    |       2018-05-04        |       2018-05-05        |      0.500       |        |",
         "|-  Range     | 2018-05-02 - 2018-05-06 | 2018-05-02 - 2018-05-07 |  0.000 - 1.000   |        |"
       )
     )
@@ -113,7 +114,7 @@ for(i in 1:3)
         "|-  FALSE     |        2 (50.0%)        |        1 (25.0%)        |    2 (100.0%)    |        |",
         "|-  TRUE      |        2 (50.0%)        |        3 (75.0%)        |    1 (50.0%)     |        |",
         "|Dat          |                         |                         |                  |   0.182|",
-        "|-  median    |       2018-05-03        |       2018-05-04        |      0.500       |        |",
+        "|-  Median    |       2018-05-03        |       2018-05-04        |      0.500       |        |",
         "|-  Range     | 2018-05-02 - 2018-05-06 | 2018-05-02 - 2018-05-07 |  0.000 - 1.000   |        |"
       )
     )
@@ -180,7 +181,7 @@ test_that("Paired with missings", {
       "|-  FALSE     |        2 (50.0%)        |        1 (25.0%)        |    2 (100.0%)    |        |",
       "|-  TRUE      |        2 (50.0%)        |        3 (75.0%)        |    1 (50.0%)     |        |",
       "|Dat          |                         |                         |                  |   0.182|",
-      "|-  median    |       2018-05-03        |       2018-05-04        |      0.500       |        |",
+      "|-  Median    |       2018-05-03        |       2018-05-04        |      0.500       |        |",
       "|-  Range     | 2018-05-02 - 2018-05-06 | 2018-05-02 - 2018-05-07 |  0.000 - 1.000   |        |"
     )
   )
@@ -188,14 +189,17 @@ test_that("Paired with missings", {
 
 test_that("09/07/2018: specifying different digits (#107) and cat.simplify (#134)", {
   expect_identical(
-    capture.kable(summary(paired(tp ~ mcnemar(Cat, digits.count = 1, digits.pct = 0, cat.simplify = TRUE) + paired.t(Num, digits = 1),
-                                 data = dat, id = id), text = TRUE)),
-    c("|             |  1 (N=4)  |  2 (N=4)  | Difference (N=4) | p value|",
-      "|:------------|:---------:|:---------:|:----------------:|-------:|",
-      "|Cat          | 2.0 (50%) | 2.0 (50%) |    1.0 (50%)     |   1.000|",
-      "|Num          |           |           |                  |   0.391|",
-      "|-  Mean (SD) | 2.8 (1.3) | 3.2 (1.0) |    0.5 (1.0)     |        |",
-      "|-  Range     | 1.0 - 4.0 | 2.0 - 4.0 |    -1.0 - 1.0    |        |"
+    capture.kable(summary(paired(tp ~ mcnemar(Cat, digits.count = 1, digits.pct = 0, cat.simplify = TRUE) + paired.t(Num, digits = 1) +
+                                   sign.test(Num2, "meansd") + paired.t(Dat, "median", date.simplify = TRUE),
+                                 data = dat, id = id, numeric.simplify = TRUE), text = TRUE)),
+    c("|             |    1 (N=4)    |    2 (N=4)    | Difference (N=4) | p value|",
+      "|:------------|:-------------:|:-------------:|:----------------:|-------:|",
+      "|Cat          |   2.0 (50%)   |   2.0 (50%)   |    1.0 (50%)     |   1.000|",
+      "|Num          |               |               |                  |   0.391|",
+      "|-  Mean (SD) |   2.8 (1.3)   |   3.2 (1.0)   |    0.5 (1.0)     |        |",
+      "|-  Range     |   1.0 - 4.0   |   2.0 - 4.0   |    -1.0 - 1.0    |        |",
+      "|Num2         | 1.500 (0.577) | 1.250 (0.957) |  -0.250 (1.500)  |   1.000|",
+      "|Dat          |  2018-05-03   |  2018-05-04   |      0.500       |   0.182|"
     )
   )
 })
